@@ -44,7 +44,7 @@ BookmarkHandler::BookmarkHandler(KActionCollection *collection, QMenu *menu, boo
         _file += QStringLiteral("/bookmarks.xml");
     }
 
-    KBookmarkManager *manager = KBookmarkManager::managerForFile(_file, QStringLiteral("konsole"));
+    KBookmarkManager *manager = new KBookmarkManager(_file, this);
     manager->setUpdate(true);
 
     // This constructor is only called with toplevel as true; regardless the
@@ -163,3 +163,5 @@ ViewProperties *BookmarkHandler::activeView() const
 {
     return _activeView;
 }
+
+#include "moc_BookmarkHandler.cpp"
