@@ -18,7 +18,6 @@
 // KDE
 #include <KLocalizedString>
 #include <QFontDatabase>
-#include <kcoreaddons_version.h>
 
 // Konsole
 #include "Enumeration.h"
@@ -33,9 +32,7 @@
 #endif // HAVE_GETPWUID
 #endif // Q_OS_WIN
 
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
 #include <KSandbox>
-#endif
 
 using namespace Konsole;
 
@@ -102,6 +99,8 @@ const std::vector<Profile::PropertyInfo> Profile::DefaultProperties = {
     {TabColor, "TabColor", APPEARANCE_GROUP, QColor(QColor::Invalid)},
     {DimValue, "DimmValue", APPEARANCE_GROUP, 128},
     {DimWhenInactive, "DimWhenInactive", GENERAL_GROUP, false},
+    {BorderWhenActive, "BorderWhenActive", APPEARANCE_GROUP, false},
+    {FocusBorderColor, "FocusBorderColor", APPEARANCE_GROUP, QColor(Qt::gray)},
     {InvertSelectionColors, "InvertSelectionColors", GENERAL_GROUP, false},
     {EmojiFont, "EmojiFont", APPEARANCE_GROUP, QFont()},
     {WordMode, "WordMode", APPEARANCE_GROUP, true},
@@ -181,11 +180,6 @@ QHash<QString, Profile::PropertyInfo> Profile::PropertyInfoByName;
 // For backward compatibility with existing profiles, it should never change.
 static const QString BUILTIN_MAGIC_PATH = QStringLiteral("FALLBACK/");
 
-// UntranslatedName property of the built-in profile, as a char array.
-//
-// Note: regular profiles created in earlier versions of Konsole may have this name too.
-static const char BUILTIN_UNTRANSLATED_NAME_CHAR[] = "Built-in";
-
 #ifdef Q_OS_WIN
 static QString checkFile(const QStringList &dirList, const QString &filePath)
 {
@@ -218,7 +212,6 @@ static QString GetWindowsShell()
 static QString defaultShell()
 {
 #ifndef Q_OS_WIN
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     if (!KSandbox::isFlatpak()) {
         return QString::fromUtf8(qgetenv("SHELL"));
     }
@@ -238,10 +231,7 @@ static QString defaultShell()
         }
     }
     return {};
-#endif
-#else
-    return QString::fromUtf8(qgetenv("SHELL"));
-#endif
+#endif // HAVE_GETPWUID
 
 #else // Q_OS_WIN
     auto shell = GetWindowPowerShell();
@@ -270,8 +260,8 @@ void Profile::useBuiltin()
     for (const PropertyInfo &propInfo : DefaultProperties) {
         setProperty(propInfo.property, propInfo.defaultValue);
     }
-    setProperty(Name, i18nc("Name of the built-in profile", BUILTIN_UNTRANSLATED_NAME_CHAR));
-    setProperty(UntranslatedName, QString::fromLatin1(BUILTIN_UNTRANSLATED_NAME_CHAR));
+    setProperty(Name, i18nc("Name of the built-in profile", "Built-in"));
+    setProperty(UntranslatedName, QStringLiteral("Built-in"));
     setProperty(Path, BUILTIN_MAGIC_PATH);
     setProperty(Command, defaultShell());
     // See Pty.cpp on why Arguments is populated
@@ -459,3 +449,5 @@ QString Profile::textEditorCmd() const
 
     return editorCmd;
 }
+
+#include "moc_Profile.cpp"
