@@ -51,6 +51,11 @@
 #include "WindowSystemInfo.h"
 #include "profile/ProfileManager.h"
 
+// Others
+#if defined(Q_OS_LINUX) | defined(Q_OS_FREEBSD) | defined(Q_OS_OPENBSD) | defined(Q_OS_SOLARIS) | defined(Q_OS_MACOS)
+#include <unistd.h>
+#endif
+
 using namespace Konsole;
 
 EditProfileDialog::EditProfileDialog(QWidget *parent)
@@ -312,6 +317,69 @@ bool EditProfileDialog::isProfileNameValid()
         return false;
     }
 
+    const QString profileStoragePath(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QDir::separator() + QStringLiteral("konsole"));
+    int nameLenMax = 256;
+
+#if defined(Q_OS_LINUX) | defined(Q_OS_OPENBSD) | defined(Q_OS_FREEBSD) | defined(Q_OS_MACOS) | defined(Q_OS_SOLARIS)
+    const int maxPath = pathconf(profileStoragePath.toLocal8Bit().constData(), _PC_PATH_MAX);
+    const int nameLenMaxPath = maxPath - _profile->path().lastIndexOf(QLatin1Char('/')) + 1;
+    const int nameLenMaxName = pathconf(profileStoragePath.toLocal8Bit().constData(), _PC_NAME_MAX);
+    nameLenMax = qMin(nameLenMaxPath, nameLenMaxName);
+#elif defined(Q_OS_WIN)
+    // If MAX_PATH not found, use default (260 - 1)
+    const int maxPath = qMax(259, qEnvironmentVariable("MAX_PATH").toInt());
+    nameLenMax = maxPath - _profile->path().lastIndexOf(QLatin1Char('/')) + 1;
+#endif
+
+    nameLenMax -= QStringLiteral(".profile").size();
+
+    if (_tempProfile->name().size() > nameLenMax) {
+        setMessageGeneralPage(i18nc("@info", "Profile name exceeded maximum allowed length (%1).", nameLenMax));
+        // Revert the name in the dialog
+        _generalUi->profileNameEdit->setText(_profile->name());
+        selectProfileName();
+        return false;
+    }
+
+    if (!_tempProfile->name().isEmpty()) {
+        static const QString illegalCharacters(QStringLiteral("#%&{}/\\\"<>*?$!':@`+=|"));
+        static const QString colorTagOpen(QStringLiteral("<font color=\"red\">"));
+        static const QString colorTagClose(QStringLiteral("</font>"));
+        const QString name(_tempProfile->name());
+        bool hasIllegal = false;
+        bool unclosedTag = false;
+        QString highlightedName;
+
+        for (int i = 0; i < name.size(); ++i) {
+            const auto currChar = name.at(i);
+
+            if (illegalCharacters.contains(currChar)) {
+                if (!unclosedTag) {
+                    highlightedName += colorTagOpen;
+                }
+                hasIllegal = true;
+                unclosedTag = true;
+            } else if (unclosedTag) {
+                unclosedTag = false;
+                highlightedName += colorTagClose;
+            }
+
+            highlightedName += currChar;
+
+            if (i + 1 == name.size() && unclosedTag) {
+                highlightedName += colorTagClose;
+            }
+        }
+
+        if (hasIllegal) {
+            setMessageGeneralPage(i18nc("@info", "The highlighted characters are invalid in profile names: %1.", highlightedName));
+            // Revert the name in the dialog
+            _generalUi->profileNameEdit->setText(_profile->name());
+            selectProfileName();
+            return false;
+        }
+    }
+
     // Valid name
     return true;
 }
@@ -629,6 +697,16 @@ void EditProfileDialog::setDimValue(int value)
     updateTempProfileProperty(Profile::DimValue, value);
 }
 
+void EditProfileDialog::setBorderWhenActive(bool value)
+{
+    updateTempProfileProperty(Profile::BorderWhenActive, value);
+}
+
+void EditProfileDialog::setFocusBorderColor(const QColor &color)
+{
+    updateTempProfileProperty(Profile::FocusBorderColor, color);
+}
+
 void EditProfileDialog::tabTitleFormatChanged(const QString &format)
 {
     updateTempProfileProperty(Profile::LocalTabTitleFormat, format);
@@ -644,6 +722,11 @@ void EditProfileDialog::tabColorChanged(const QColor &color)
     updateTempProfileProperty(Profile::TabColor, color);
 }
 
+void EditProfileDialog::focusBorderColorChanged(const QColor &color)
+{
+    updateTempProfileProperty(Profile::FocusBorderColor, color);
+}
+
 void EditProfileDialog::silenceSecondsChanged(int seconds)
 {
     updateTempProfileProperty(Profile::SilenceSeconds, seconds);
@@ -829,6 +912,14 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
     _appearanceUi->dimLabel->setEnabled(profile->dimWhenInactive());
     connect(_appearanceUi->dimValue, &QSlider::valueChanged, this, &Konsole::EditProfileDialog::setDimValue);
 
+    _appearanceUi->borderWhenActiveCheckbox->setChecked(profile->borderWhenActive());
+    connect(_appearanceUi->borderWhenActiveCheckbox, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::setBorderWhenActive);
+
+    _appearanceUi->focusBorderColor->setColor(profile->focusBorderColor());
+    _appearanceUi->focusBorderColor->setEnabled(profile->borderWhenActive());
+    _appearanceUi->borderLabel->setEnabled(profile->borderWhenActive());
+    connect(_appearanceUi->focusBorderColor, &KColorButton::changed, this, &Konsole::EditProfileDialog::focusBorderColorChanged);
+
     _appearanceUi->invertSelectionColorsCheckbox->setChecked(profile->property<bool>(Profile::InvertSelectionColors));
     connect(_appearanceUi->invertSelectionColorsCheckbox, &QCheckBox::toggled, this, [this](bool checked) {
         updateTempProfileProperty(Profile::InvertSelectionColors, checked);
@@ -840,13 +931,9 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
     _appearanceUi->displayVerticalLineAtColumn->setValue(profile->verticalLineAtChar());
     connect(_appearanceUi->displayVerticalLineAtColumn, QOverload<int>::of(&QSpinBox::valueChanged), this, &EditProfileDialog::setVerticalLineColumn);
 
-#if KNEWSTUFF_VERSION >= QT_VERSION_CHECK(5, 91, 0)
     auto *getNewButton = new KNSWidgets::Button(this);
     connect(getNewButton, &KNSWidgets::Button::dialogFinished, this, &Konsole::EditProfileDialog::gotNewColorSchemes);
-#else
-    auto *getNewButton = new KNS3::Button(this);
-    connect(getNewButton, &KNS3::Button::dialogFinished, this, &Konsole::EditProfileDialog::gotNewColorSchemes);
-#endif
+
     getNewButton->setText(QStringLiteral("Get New..."));
     getNewButton->setConfigFile(QStringLiteral("konsole.knsrc"));
     _appearanceUi->colorSchemesBtnLayout->addWidget(getNewButton);
@@ -1222,16 +1309,12 @@ void EditProfileDialog::removeColorScheme()
     }
 }
 
-#if KNEWSTUFF_VERSION >= QT_VERSION_CHECK(5, 91, 0)
-void EditProfileDialog::gotNewColorSchemes(const QList<KNSCore::EntryInternal> &changedEntries)
-#else
-void EditProfileDialog::gotNewColorSchemes(const KNS3::Entry::List &changedEntries)
-#endif
+void EditProfileDialog::gotNewColorSchemes(const QList<KNSCore::Entry> &changedEntries)
 {
     int failures = 0;
-    for (auto &entry : qAsConst(changedEntries)) {
+    for (auto &entry : std::as_const(changedEntries)) {
         switch (entry.status()) {
-        case KNS3::Entry::Installed:
+        case KNSCore::Entry::Installed:
             for (const QString &file : entry.installedFiles()) {
                 if (ColorSchemeManager::instance()->loadColorScheme(file)) {
                     continue;
@@ -1245,7 +1328,7 @@ void EditProfileDialog::gotNewColorSchemes(const KNS3::Entry::List &changedEntri
                 QTimer::singleShot(8000, _appearanceUi->colorSchemeMessageWidget, &KMessageWidget::animatedHide);
             }
             break;
-        case KNS3::Entry::Deleted:
+        case KNSCore::Entry::Deleted:
             for (const auto &file : entry.uninstalledFiles()) {
                 if (ColorSchemeManager::instance()->unloadColorScheme(file)) {
                     continue;
@@ -1255,11 +1338,11 @@ void EditProfileDialog::gotNewColorSchemes(const KNS3::Entry::List &changedEntri
                 // it either wasn't loaded or was invalid to begin with.
             }
             break;
-        case KNS3::Entry::Invalid:
-        case KNS3::Entry::Installing:
-        case KNS3::Entry::Downloadable:
-        case KNS3::Entry::Updateable:
-        case KNS3::Entry::Updating:
+        case KNSCore::Entry::Invalid:
+        case KNSCore::Entry::Installing:
+        case KNSCore::Entry::Downloadable:
+        case KNSCore::Entry::Updateable:
+        case KNSCore::Entry::Updating:
             // Not interesting.
             break;
         }
@@ -1871,21 +1954,10 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr &profile)
     auto codecAction = new KCodecAction(this);
     codecAction->setCurrentCodec(profile->defaultEncoding());
     _advancedUi->selectEncodingButton->setMenu(codecAction->menu());
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 103, 0)
-    connect(codecAction,
-#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
-            QOverload<QTextCodec *>::of(&KCodecAction::codecTriggered),
-            this,
-#else
-            QOverload<QTextCodec *>::of(&KCodecAction::triggered),
-            this,
-#endif
-            &Konsole::EditProfileDialog::setDefaultCodec);
-#else
-    connect(codecAction, &KCodecAction::codecNameTriggered, this, [this](const QString &codecName) {
-        setDefaultCodec(QTextCodec::codecForName(codecName.toUtf8()));
+
+    connect(codecAction, &KCodecAction::codecNameTriggered, this, [this](const QByteArray &codecName) {
+        setDefaultCodec(QTextCodec::codecForName(codecName));
     });
-#endif
 
     connect(codecAction, &KCodecAction::defaultItemTriggered, this, [this] {
         setDefaultCodec(QTextCodec::codecForLocale());
@@ -1922,12 +1994,7 @@ int EditProfileDialog::maxSpinBoxWidth(const KPluralHandlingSpinBox *spinBox, co
     opt.frame = spinBox->hasFrame();
 
     const QSize hint(width, spinBox->sizeHint().height());
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     const QSize spinBoxSize = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, spinBox);
-#else
-    const QSize spinBoxSize = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, spinBox).expandedTo(QApplication::globalStrut());
-#endif
-
     return spinBoxSize.width();
 }
 
@@ -2097,3 +2164,5 @@ void EditProfileDialog::toggleIgnoreWcWidth(bool ignore)
 {
     updateTempProfileProperty(Profile::IgnoreWcWidth, ignore);
 }
+
+#include "moc_EditProfileDialog.cpp"
