@@ -128,6 +128,7 @@ public:
     void moveTabToWindow(int index, QWidget *window);
 
     void toggleMaximizeCurrentTerminal();
+    void toggleZoomMaximizeCurrentTerminal();
     /* return the widget(int index) casted to TerminalDisplay*
      *
      * The only thing that this class holds are TerminalDisplays, so
@@ -202,7 +203,7 @@ Q_SIGNALS:
     /** set the color tab */
     void setColor(int index, const QColor &color);
 
-    /** remve the color tab */
+    /** remove the color tab */
     void removeColor(int idx);
 
 protected:
@@ -244,7 +245,6 @@ private:
     QToolButton *_newTabButton;
     QToolButton *_closeTabButton;
     int _contextMenuTabIndex;
-    ViewManager::NavigationVisibility _navigationVisibility;
     NewTabBehavior _newTabBehavior;
 };
 
