@@ -19,6 +19,8 @@
 
 // Konsole
 #include "terminalDisplay/TerminalDisplay.h"
+#include "terminalDisplay/TerminalFonts.h"
+#include "terminalDisplay/TerminalScrollBar.h"
 #include "widgets/ViewContainer.h"
 
 using Konsole::TerminalDisplay;
@@ -146,6 +148,15 @@ void ViewSplitter::childEvent(QChildEvent *event)
                 auto *parent_splitter = qobject_cast<ViewSplitter *>(parent());
                 if (parent_splitter) {
                     parent_splitter->m_blockPropagatedDeletion = true;
+
+                    // Force recalculation of sizes to take into account recent
+                    // setVisible(true) calls due to a clearMaximize() upon
+                    // sessionFinished. Without the refresh() call, the size of
+                    // a previously hidden splitter could still be 0. The
+                    // documentation of refresh() says "You should not need to
+                    // call this function", but it seems we do.
+                    parent_splitter->refresh();
+
                     const auto sizes = parent_splitter->sizes();
                     auto *wdg = widget(0);
                     const int oldContainerIndex = parent_splitter->indexOf(this);
@@ -243,7 +254,13 @@ TerminalDisplay *ViewSplitter::activeTerminalDisplay() const
 void ViewSplitter::toggleMaximizeCurrentTerminal()
 {
     m_terminalMaximized = !m_terminalMaximized;
-    handleMinimizeMaximize(m_terminalMaximized);
+    handleMinimizeMaximize(m_terminalMaximized, false);
+}
+
+void ViewSplitter::toggleZoomMaximizeCurrentTerminal()
+{
+    m_terminalMaximized = !m_terminalMaximized;
+    handleMinimizeMaximize(m_terminalMaximized, true);
 }
 
 namespace
@@ -283,12 +300,41 @@ bool ViewSplitter::hideRecurse(TerminalDisplay *currentTerminalDisplay)
     return allHidden;
 }
 
-void ViewSplitter::handleMinimizeMaximize(bool maximize)
+void ViewSplitter::handleMinimizeMaximize(bool maximize, bool zoom)
 {
     auto topLevelSplitter = getToplevelSplitter();
     auto currentTerminalDisplay = topLevelSplitter->activeTerminalDisplay();
     currentTerminalDisplay->setExpandedMode(maximize);
+
+    auto currentTerminalFont = currentTerminalDisplay->terminalFont()->getVTFont();
+
     if (maximize) {
+        if (zoom) {
+            fontSizeBeforeMaximization = currentTerminalFont.pointSizeF();
+            auto headerBar = currentTerminalDisplay->headerBar();
+            auto headerBarHeight = headerBar->isVisible() ? headerBar->height() : 0;
+            auto scrollBar = currentTerminalDisplay->scrollBar();
+            auto scrollBarWidth = scrollBar->scrollBarPosition() != Enum::ScrollBarHidden ? scrollBar->width() : 0;
+
+            // This is very inexact, which is fine, because the aspect ratio of
+            // both the scaled font and the terminal can differ anyway.
+            auto scaleFactor = std::min(
+                (topLevelSplitter->width() - scrollBarWidth)
+                / (currentTerminalDisplay->width() - scrollBarWidth),
+
+                (topLevelSplitter->height() - headerBarHeight)
+                / (currentTerminalDisplay->height() - headerBarHeight)
+            );
+            auto newSize = int(fontSizeBeforeMaximization * scaleFactor * 0.97);
+
+            if (newSize > fontSizeBeforeMaximization) {
+                currentTerminalFont.setPointSizeF(newSize);
+                currentTerminalDisplay->terminalFont()->setVTFont(currentTerminalFont);
+            }
+        } else {
+            fontSizeBeforeMaximization = 0;
+        }
+
         for (int i = 0, end = topLevelSplitter->count(); i < end; i++) {
             auto widgetAt = topLevelSplitter->widget(i);
             if (auto *maybeSplitter = qobject_cast<ViewSplitter *>(widgetAt)) {
@@ -301,6 +347,15 @@ void ViewSplitter::handleMinimizeMaximize(bool maximize)
             }
         }
     } else {
+        // When restoring to un-maximzed state, it doesn't matter if this is done through
+        // toggleMaximizeCurrentTerminal or toggleZoomMaximizeCurrentTerminal.
+        // Only the method which was used to maximize, determines if the font size needs
+        // to be restored.
+        if (fontSizeBeforeMaximization) {
+            currentTerminalFont.setPointSizeF(fontSizeBeforeMaximization);
+            currentTerminalDisplay->terminalFont()->setVTFont(currentTerminalFont);
+        }
+
         restoreAll(topLevelSplitter->findChildren<TerminalDisplay *>(), topLevelSplitter->findChildren<ViewSplitter *>());
     }
 }
@@ -346,7 +401,7 @@ void Konsole::ViewSplitter::dragEnterEvent(QDragEnterEvent *ev)
 
 void Konsole::ViewSplitter::dragMoveEvent(QDragMoveEvent *ev)
 {
-    auto currentWidget = childAt(ev->pos());
+    auto currentWidget = childAt(ev->position().toPoint());
     if (auto terminal = qobject_cast<TerminalDisplay *>(currentWidget)) {
         if ((currentDragTarget != nullptr) && currentDragTarget != terminal) {
             currentDragTarget->hideDragTarget();
@@ -355,7 +410,7 @@ void Konsole::ViewSplitter::dragMoveEvent(QDragMoveEvent *ev)
             return;
         }
         currentDragTarget = terminal;
-        auto localPos = currentDragTarget->mapFromParent(ev->pos());
+        auto localPos = currentDragTarget->mapFromParent(ev->position().toPoint());
         currentDragTarget->showDragTarget(localPos);
     }
 }
@@ -562,3 +617,5 @@ void Konsole::ViewSplitterHandle::mouseDoubleClickEvent(QMouseEvent *ev)
     mouseReleaseEventCounter = 0;
     QSplitterHandle::mouseDoubleClickEvent(ev);
 }
+
+#include "moc_ViewSplitter.cpp"
